@@ -3,6 +3,7 @@ import warnings
 from scipy import stats
 from math import sqrt
 from sklearn import linear_model
+from abc import ABCMeta, abstractmethod
 from sklearn.ensemble import RandomForestRegressor
 from sklearn.model_selection import GridSearchCV
 from sklearn.metrics import mean_squared_error
@@ -17,7 +18,7 @@ __all__ = ['HRFRegressor',
 sep = Handler().sep
 
 
-class _Regressor(object):
+class _Regressor(object, metaclass=ABCMeta):
     """
     Regressor base class
     """
@@ -126,6 +127,13 @@ class _Regressor(object):
         else:
             raise ValueError("Model not initialized with samples")
 
+    @abstractmethod
+    def predict(self, *args, **kwargs):
+        """
+        Placeholder of subclass predict() methods
+        """
+        pass
+
     @staticmethod
     def param_grid(param_dict):
         """
@@ -403,7 +411,7 @@ class _Regressor(object):
         kwargs.update({'out_data_type':
                        gdal_array.NumericTypeCodeToGDALTypeCode(regressor.data['labels'].dtype)})
 
-        defaults = _Regressor.get_defaults(raster=raster_obj,
+        defaults = regressor.get_defaults(raster=raster_obj,
                                            **kwargs)
 
         verbose = defaults['verbose'] if 'verbose' in defaults else False
@@ -1024,7 +1032,7 @@ class RFRegressor(_Regressor):
         if uncert_dict is None or len(uncert_dict) == 0:
             raise RuntimeError("No uncertainty band dictionary provided")
 
-        if type(regressor) != _Regressor:
+        if type(regressor) != RFRegressor:
             raise RuntimeError("Regressor must be supplied to calculate uncertainty ranges" +
                                "Regressor must be of _Regressor class")
 
@@ -1251,11 +1259,6 @@ class RFRegressor(_Regressor):
             lm = self.linear_regress(data['labels'],
                                      prediction)
 
-        if np.any(np.isinf(prediction)) or np.any(np.isnan(prediction)):
-            loc = np.where(np.isfinite(prediction))
-            data['labels'] = data['labels'][loc]
-            prediction = prediction[loc]
-
         rmse = sqrt(mean_squared_error(data['labels'], prediction))
 
         # if outfile and pickle file are not provided,
@@ -1382,17 +1385,17 @@ class HRFRegressor(RFRegressor):
         self.feature_index = list(list(raster_obj.bnames.index(feat) for feat in feat_grp)
                                   for feat_grp in self.features)
 
-        return _Regressor.regress_raster(self,
-                                         raster_obj,
-                                         outfile=outfile,
-                                         outdir=outdir,
-                                         band_name=band_name,
-                                         output_type=output_type,
-                                         out_data_type=out_data_type,
-                                         nodatavalue=nodatavalue,
-                                         array_multiplier=array_multiplier,
-                                         array_additive=array_additive,
-                                         **kwargs)
+        return super(HRFRegressor, self).regress_raster(self,
+                                                        raster_obj,
+                                                        outfile=outfile,
+                                                        outdir=outdir,
+                                                        band_name=band_name,
+                                                        output_type=output_type,
+                                                        out_data_type=out_data_type,
+                                                        nodatavalue=nodatavalue,
+                                                        array_multiplier=array_multiplier,
+                                                        array_additive=array_additive,
+                                                        **kwargs)
 
     def predict(self,
                 arr,
